@@ -17,6 +17,15 @@ def xml_to_dict(fname):
     return data
 
 
+def get_factors(x, start=2):
+    """Get factors of a number."""
+    facts = []
+    for i in range(start, x + 1):
+        if x % i == 0:
+            facts.append(i)
+    return facts
+
+
 def get_counts(array=["W", "W", "Mo", "Mo", "S", "S"]):
     """
     Get number of unique elements and their counts.
@@ -266,14 +275,7 @@ def digitize_array(values=[], max_len=10):
 
 
 def bond_angle(
-    dist1,
-    dist2,
-    bondx1,
-    bondx2,
-    bondy1,
-    bondy2,
-    bondz1,
-    bondz2,
+    dist1, dist2, bondx1, bondx2, bondy1, bondy2, bondz1, bondz2,
 ):
     """Get an angle."""
     nm = dist1 * dist2
@@ -300,6 +302,26 @@ def check_url_exists(
         return False
 
 
+def volumetric_grid_reshape(data=[], final_grid=[50, 50, 50]):
+    """Reshape volumetric data."""
+    import torch
+
+    data = torch.tensor(data).unsqueeze(0).unsqueeze(0)
+    new_data = (
+        torch.nn.functional.interpolate(
+            data,
+            size=final_grid,
+            scale_factor=None,
+            mode="trilinear",
+            align_corners=True,
+            recompute_scale_factor=None,
+        )
+        .squeeze()
+        .squeeze()
+    )
+    return new_data.numpy()
+
+
 def cos_formula(a, b, c):
     """Get angle between three edges for oblique triangles."""
     res = (a ** 2 + b ** 2 - c ** 2) / (2 * a * b)
